@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <errno.h>
 #include <stdlib.h>
@@ -165,7 +164,7 @@ int Kwave::MenuManager::executeCommand(const QString &command)
         QRegularExpression rx{_("::(\\w+)"),
             QRegularExpression::CaseInsensitiveOption};
         QRegularExpressionMatch match;
-        int p = 0;
+        qsizetype p = 0;
         while ((p = param.indexOf(rx, 0, &match)) >= 0) {
             QString stdname = match.captured(1);
             if (m_standard_keys.contains(stdname)) {
@@ -176,7 +175,8 @@ int Kwave::MenuManager::executeCommand(const QString &command)
             } else {
                 // unknown standard key sequence name?
                 qWarning("MenuManager::executeCommand: pos=%d, stdname='%s' "
-                         "-> UNKNOWN ???", p, DBG(stdname));
+                         "-> UNKNOWN ???",
+                         static_cast<int>(p), DBG(stdname));
                 break;
             }
         }
@@ -218,7 +218,7 @@ int Kwave::MenuManager::executeCommand(const QString &command)
 void Kwave::MenuManager::clearNumberedMenu(const QString &uid)
 {
     Kwave::MenuNode *node = (m_menu_root) ?
-        m_menu_root->findUID(uid) : Q_NULLPTR;
+        m_menu_root->findUID(uid) : nullptr;
     if (node) node->clear();
 }
 
@@ -232,8 +232,8 @@ void Kwave::MenuManager::addNumberedMenuEntry(const QString &uid,
 
     Q_ASSERT(m_menu_root);
     Kwave::MenuNode *node = (m_menu_root) ? m_menu_root->findUID(uid) :
-                                            Q_NULLPTR;
-    Kwave::MenuNode *parent = (node) ? node->parentNode() : Q_NULLPTR;
+                                            nullptr;
+    Kwave::MenuNode *parent = (node) ? node->parentNode() : nullptr;
     if (parent) {
         QString cmd = node->command();
         if (cmd.contains(_("%1"))) {
@@ -280,7 +280,7 @@ void Kwave::MenuManager::selectItem(const QString &group, const QString &uid)
 void Kwave::MenuManager::setItemChecked(const QString &uid, bool check)
 {
     Kwave::MenuNode *node = (m_menu_root) ?
-        m_menu_root->findUID(uid) : Q_NULLPTR;
+        m_menu_root->findUID(uid) : nullptr;
     if (node) node->setChecked(check);
 }
 
@@ -288,7 +288,7 @@ void Kwave::MenuManager::setItemChecked(const QString &uid, bool check)
 void Kwave::MenuManager::setItemText(const QString &uid, const QString &text)
 {
     Kwave::MenuNode *node = (m_menu_root) ?
-        m_menu_root->findUID(uid) : Q_NULLPTR;
+        m_menu_root->findUID(uid) : nullptr;
     if (node) node->setText(text);
 }
 
@@ -339,8 +339,10 @@ void Kwave::MenuManager::setItemEnabled(const QString &uid, bool enable)
 Kwave::MenuManager::~MenuManager()
 {
     delete m_menu_root;
-    m_menu_root = Q_NULLPTR;
+    m_menu_root = nullptr;
 }
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_MenuManager.cpp"
